==> kwayland-integration_5.14.5.orig.tar.xz: kwayland-integration-5.14.5/src/windowsystem/plugin.cpp <==
/*
 * Copyright 2015 Martin Gräßlin <mgraesslin@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) version 3, or any
 * later version accepted by the membership of KDE e.V. (or its
 * successor approved by the membership of KDE e.V.), which shall
 * act as a proxy defined in Section 6 of version 3 of the license.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "plugin.h"
#include "windowsystem.h"
#include "windoweffects.h"
#include "windowinfo.h"

KWaylandPlugin::KWaylandPlugin(QObject *parent)
    : KWindowSystemPluginInterface(parent)
{
}

KWaylandPlugin::~KWaylandPlugin()
{
}

KWindowEffectsPrivate *KWaylandPlugin::createEffects()
{
    return new WindowEffects();
}

KWindowSystemPrivate *KWaylandPlugin::createWindowSystem()
{
    return new WindowSystem();
}

KWindowInfoPrivate *KWaylandPlugin::createWindowInfo(WId window, NET::Properties properties, NET::Properties2 properties2)
{
    return new WindowInfo(window, properties, properties2);
}

==> kwayland-integration_5.20.5.orig.tar.xz: kwayland-integration-5.20.5/src/windowsystem/plugin.cpp <==
/*
 * Copyright 2015 Martin Gräßlin <mgraesslin@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) version 3, or any
 * later version accepted by the membership of KDE e.V. (or its
 * successor approved by the membership of KDE e.V.), which shall
 * act as a proxy defined in Section 6 of version 3 of the license.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */
#include "plugin.h"
#include "windowshadow.h"
#include "windowsystem.h"
#include "windoweffects.h"
#include "windowinfo.h"

KWaylandPlugin::KWaylandPlugin(QObject *parent)
    : KWindowSystemPluginInterface(parent)
{
}

KWaylandPlugin::~KWaylandPlugin()
{
}

KWindowEffectsPrivate *KWaylandPlugin::createEffects()
{
    return new WindowEffects();
}

KWindowSystemPrivate *KWaylandPlugin::createWindowSystem()
{
    return new WindowSystem();
}

KWindowInfoPrivate *KWaylandPlugin::createWindowInfo(WId window, NET::Properties properties, NET::Properties2 properties2)
{
    return new WindowInfo(window, properties, properties2);
}

KWindowShadowTilePrivate *KWaylandPlugin::createWindowShadowTile()
{
    return new WindowShadowTile();
}

KWindowShadowPrivate *KWaylandPlugin::createWindowShadow()
{
    return new WindowShadow();
}
